/***********************************************************************/
/*    ALRTGLBL.H - Structure definitions and defines that are shared   */
/*                 between the ALERTCOM.DLL and ACP.NLM modules.       */
/*                                                                     */
/*    Copyright (c) e. g. Software Inc, 1993.  All Rights Reserved.    */
/*                                                                     */
/*                e. g. Software Inc.                                  */
/*                319 SW Washington Suite 706                          */
/*                Portland OR, 97204                                   */
/*                (503) 294-7025                                       */
/*                (503) 294-7130 FAX                                   */
/*                                                                     */
/***********************************************************************/


#define	OT_ALERTTRACK_SERVER	0x07F3


#define PACKET_TYPE_RECIPIENT      0
#define PACKET_TYPE_PAGER          1
#define PACKET_TYPE_ANPAGER        2
#define PACKET_TYPE_MHS            3
#define PACKET_TYPE_BROADCAST      4
#define PACKET_TYPE_SNMP           5
#define PACKET_TYPE_PEGASUS        6
#define PACKET_TYPE_FAXWARE        7


/****************************************************************************/
/* This packet structure is for sending an alert to a pre defined recipient */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  BYTE yReserved[512-(1+256+48+48+1)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET, * LP_ALERT_DATA_PACKET;
#else
} ALERT_DATA_PACKET, far * LP_ALERT_DATA_PACKET;
#endif


/****************************************************************************/
/* This packet is for sending an alert to anyone using a numeric pager      */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  BYTE szPhoneNumber[30];
  char szMessageCode[30];
  BYTE yReserved[512-(1+48+48+256+1+30+30)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET_PAGER, * LP_ALERT_DATA_PACKET_PAGER;
#else
} ALERT_DATA_PACKET_PAGER, far * LP_ALERT_DATA_PACKET_PAGER;
#endif

/****************************************************************************/
/* This packet is for sending an alert to anyone using a alphanumeric pager */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  char szServicePhoneNumber[30];
  char szPagerNumber[30];
  BYTE yReserved[512-(1+256+48+48+1+30+30)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET_ANPAGER, * LP_ALERT_DATA_PACKET_ANPAGER;
#else
} ALERT_DATA_PACKET_ANPAGER, far * LP_ALERT_DATA_PACKET_ANPAGER;
#endif

/****************************************************************************/
/* This packet is for sending an alert to anyone using MHS                  */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  char szMHSServer  [20];           /* MHS Server                      */
  char szMHSPath    [64];           /* Path to MHS directory (SYS:MHS) */
  char szMHSUserName[20];           /* Routing user name               */
  char szPassword   [20];           /* Routing Password                */


  BYTE yReserved[512-(1+256+48+48+1+20+64+20+20)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET_MHS, * LP_ALERT_DATA_PACKET_MHS;
#else
} ALERT_DATA_PACKET_MHS, far * LP_ALERT_DATA_PACKET_MHS;
#endif

/****************************************************************************/
/* This packet is for sending an alert to anyone using SNMP                 */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  BYTE yReserved[512-(1+256+48+48+1)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET_SNMP, * LP_ALERT_DATA_PACKET_SNMP;
#else
} ALERT_DATA_PACKET_SNMP, far * LP_ALERT_DATA_PACKET_SNMP;
#endif

/****************************************************************************/
/* This packet is for sending an alert to anyone using network broadcast    */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  char szToServer       [20];       /* Server name                     */
  char szRoutingUser    [20];       /* Routing user name               */
  char szRoutingPassword[20];       /* Routing Password                */
  BYTE yReserved[512-(1+256+48+48+1+20+20+20)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET_BROADCAST, * LP_ALERT_DATA_PACKET_BROADCAST;
#else
} ALERT_DATA_PACKET_BROADCAST, far * LP_ALERT_DATA_PACKET_BROADCAST;
#endif

/****************************************************************************/
/* This packet is for sending an alert to anyone using faxware              */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  char szToFaxNumber[30];
  char szFaxWareServer[20];
  char szFaxWareUserName[20];
  char szPassword[20];
  BYTE yReserved[512-(1+256+48+48+1+30+20+20+20)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET_FAXWARE, * LP_ALERT_DATA_PACKET_FAXWARE;
#else
} ALERT_DATA_PACKET_FAXWARE, far * LP_ALERT_DATA_PACKET_FAXWARE;
#endif

/****************************************************************************/
/* This packet is for sending an alert to anyone using pegasus mail         */
/****************************************************************************/
typedef struct
{
  BYTE yPacketType;
  char szRecipientName[48];         /* send the message to this person */
  char szFromAppName[48];           /* Message is from application     (optional - send "" for any application*/
  char szMessage[256];              /* the message                     */
  BYTE yPriority;                   /* priority  0-9 (9 highest)       */
  char szPegasusServer[20];
  char szPegasusUserName[20];
  char szPassword[20];
  BYTE yReserved[512-(1+256+48+48+1+20+20+20)];

#ifdef	_NETWARE_NLM	// NO far parameter
} ALERT_DATA_PACKET_PEGASUS, * LP_ALERT_DATA_PACKET_PEGASUS;
#else
} ALERT_DATA_PACKET_PEGASUS, far * LP_ALERT_DATA_PACKET_PEGASUS;
#endif
